@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -15,11 +15,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_CONFIG_H
-#define WEECHAT_CONFIG_H 1
+#define WEECHAT_CONFIG_H
 
 #include <regex.h>
 #include <wctype.h>
@@ -229,6 +229,7 @@ extern struct t_config_option *config_look_read_marker;
 extern struct t_config_option *config_look_read_marker_always_show;
 extern struct t_config_option *config_look_read_marker_string;
 extern struct t_config_option *config_look_save_config_on_exit;
+extern struct t_config_option *config_look_save_config_with_fsync;
 extern struct t_config_option *config_look_save_layout_on_exit;
 extern struct t_config_option *config_look_scroll_amount;
 extern struct t_config_option *config_look_scroll_bottom_after_switch;
@@ -319,6 +320,7 @@ extern struct t_config_option *config_completion_partial_completion_command;
 extern struct t_config_option *config_completion_partial_completion_command_arg;
 extern struct t_config_option *config_completion_partial_completion_count;
 extern struct t_config_option *config_completion_partial_completion_other;
+extern struct t_config_option *config_completion_partial_completion_templates;
 
 extern struct t_config_option *config_history_display_default;
 extern struct t_config_option *config_history_max_buffer_lines_minutes;
@@ -353,6 +355,7 @@ extern int config_word_chars_input_count;
 extern char **config_nick_colors;
 extern int config_num_nick_colors;
 extern struct t_hashtable *config_hashtable_nick_color_force;
+extern struct t_hashtable *config_hashtable_completion_partial_templates;
 
 extern void config_set_nick_colors ();
 extern struct t_config_option *config_weechat_debug_get (const char *plugin_name);
