@@ -1,7 +1,7 @@
 /*
  * wee-eval.c - evaluate expressions with references to internal vars
  *
- * Copyright (C) 2012-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2012-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -50,16 +50,10 @@ char *comparisons[EVAL_NUM_COMPARISONS] =
 { "=~", "!~", "=*", "!*", "==", "!=", "<=", "<", ">=", ">" };
 
 
-char *eval_replace_vars (const char *expr, struct t_hashtable *pointers,
-                         struct t_hashtable *extra_vars, int extra_vars_eval,
-                         const char *prefix, const char *suffix,
-                         struct t_eval_regex *eval_regex);
+char *eval_replace_vars (const char *expr,
+                         struct t_eval_context *eval_context);
 char *eval_expression_condition (const char *expr,
-                                 struct t_hashtable *pointers,
-                                 struct t_hashtable *extra_vars,
-                                 int extra_vars_eval,
-                                 const char *prefix,
-                                 const char *suffix);
+                                 struct t_eval_context *eval_context);
 
 
 /*
@@ -162,7 +156,7 @@ eval_hdata_get_value (struct t_hdata *hdata, void *pointer, const char *path)
     if (!path || !path[0])
     {
         snprintf (str_value, sizeof (str_value),
-                  "0x%lx", (long unsigned int)pointer);
+                  "0x%lx", (unsigned long)pointer);
         return strdup (str_value);
     }
 
@@ -211,7 +205,7 @@ eval_hdata_get_value (struct t_hdata *hdata, void *pointer, const char *path)
         case WEECHAT_HDATA_POINTER:
             pointer = hdata_pointer (hdata, pointer, var_name);
             snprintf (str_value, sizeof (str_value),
-                      "0x%lx", (long unsigned int)pointer);
+                      "0x%lx", (unsigned long)pointer);
             value = strdup (str_value);
             break;
         case WEECHAT_HDATA_TIME:
@@ -244,7 +238,7 @@ eval_hdata_get_value (struct t_hdata *hdata, void *pointer, const char *path)
                         case HASHTABLE_POINTER:
                         case HASHTABLE_BUFFER:
                             snprintf (str_value, sizeof (str_value),
-                                      "0x%lx", (long unsigned int)ptr_value);
+                                      "0x%lx", (unsigned long)ptr_value);
                             value = strdup (str_value);
                             break;
                         case HASHTABLE_TIME:
@@ -260,7 +254,7 @@ eval_hdata_get_value (struct t_hdata *hdata, void *pointer, const char *path)
             else
             {
                 snprintf (str_value, sizeof (str_value),
-                          "0x%lx", (long unsigned int)pointer);
+                          "0x%lx", (unsigned long)pointer);
                 value = strdup (str_value);
             }
             break;
@@ -299,15 +293,17 @@ end:
  *   5. a string with max chars (format: cut:max,suffix,string or
  *      cut:+max,suffix,string) or max chars on screen
  *      (format: cutscr:max,suffix,string or cutscr:+max,suffix,string)
- *   6. a regex group captured (format: re:N (0.99) or re:+)
- *   7. a color (format: color:xxx)
- *   8. an info (format: info:name,arguments)
- *   9. current date/time (format: date or date:xxx)
- *  10. an environment variable (format: env:XXX)
- *  11. a ternary operator (format: if:condition?value_if_true:value_if_false)
- *  12. an option (format: file.section.option)
- *  13. a buffer local variable
- *  14. a hdata variable (format: hdata.var1.var2 or hdata[list].var1.var2
+ *   6. a reversed string (format: rev:xxx)
+ *   7. a repeated string (format: repeat:count,string)
+ *   8. a regex group captured (format: re:N (0.99) or re:+)
+ *   9. a color (format: color:xxx)
+ *  10. an info (format: info:name,arguments)
+ *  11. current date/time (format: date or date:xxx)
+ *  12. an environment variable (format: env:XXX)
+ *  13. a ternary operator (format: if:condition?value_if_true:value_if_false)
+ *  14. an option (format: file.section.option)
+ *  15. a buffer local variable
+ *  16. a hdata variable (format: hdata.var1.var2 or hdata[list].var1.var2
  *                        or hdata[ptr].var1.var2)
  *
  * See /help in WeeChat for examples.
@@ -318,46 +314,38 @@ end:
 char *
 eval_replace_vars_cb (void *data, const char *text)
 {
-    struct t_hashtable *pointers, *extra_vars;
-    struct t_eval_regex *eval_regex;
+    struct t_eval_context *eval_context;
     struct t_config_option *ptr_option;
     struct t_gui_buffer *ptr_buffer;
     char str_value[512], *value, *pos, *pos1, *pos2, *hdata_name, *list_name;
-    char *tmp, *info_name, *hide_char, *hidden_string, *error, *condition;
-    const char *prefix, *suffix, *ptr_value, *ptr_arguments, *ptr_string;
+    char *tmp, *tmp2, *info_name, *hide_char, *hidden_string, *error;
+    char *condition;
+    const char *ptr_value, *ptr_arguments, *ptr_string;
     struct t_hdata *hdata;
     void *pointer;
-    int i, length_hide_char, length, index, rc, extra_vars_eval, screen;
+    int i, length_hide_char, length, index, rc, screen;
     int count_suffix;
     long number;
-    long unsigned int ptr;
+    unsigned long ptr;
     time_t date;
     struct tm *date_tmp;
 
-    pointers = (struct t_hashtable *)(((void **)data)[0]);
-    extra_vars = (struct t_hashtable *)(((void **)data)[1]);
-    extra_vars_eval = *(int *)(((void **)data)[2]);
-    prefix = (const char *)(((void **)data)[3]);
-    suffix = (const char *)(((void **)data)[4]);
-    eval_regex = (struct t_eval_regex *)(((void **)data)[5]);
+    eval_context = (struct t_eval_context *)data;
 
     /* 1. variable in hashtable "extra_vars" */
-    if (extra_vars)
+    if (eval_context->extra_vars)
     {
-        ptr_value = hashtable_get (extra_vars, text);
+        ptr_value = hashtable_get (eval_context->extra_vars, text);
         if (ptr_value)
         {
-            if (extra_vars_eval)
+            if (eval_context->extra_vars_eval)
             {
                 tmp = strdup (ptr_value);
                 if (!tmp)
                     return NULL;
-                hashtable_remove (extra_vars, text);
-                value = eval_replace_vars (tmp, pointers,
-                                           extra_vars, extra_vars_eval,
-                                           prefix, suffix,
-                                           eval_regex);
-                hashtable_set (extra_vars, text, tmp);
+                hashtable_remove (eval_context->extra_vars, text);
+                value = eval_replace_vars (tmp, eval_context);
+                hashtable_set (eval_context->extra_vars, text, tmp);
                 free (tmp);
                 return value;
             }
@@ -374,10 +362,7 @@ eval_replace_vars_cb (void *data, const char *text)
      */
     if (strncmp (text, "eval:", 5) == 0)
     {
-        return eval_replace_vars (text + 5, pointers,
-                                  extra_vars, extra_vars_eval,
-                                  prefix, suffix,
-                                  eval_regex);
+        return eval_replace_vars (text + 5, eval_context);
     }
 
     /* 3. convert escaped chars */
@@ -466,17 +451,42 @@ eval_replace_vars_cb (void *data, const char *text)
         return value;
     }
 
-    /* 6. regex group captured */
+    /* 6. reverse string */
+    if (strncmp (text, "rev:", 4) == 0)
+    {
+        return string_reverse (text + 4);
+    }
+
+    /* 7. repeated string */
+    if (strncmp (text, "repeat:", 7) == 0)
+    {
+        pos = strchr (text + 7, ',');
+        if (!pos)
+            return strdup ("");
+        tmp = strndup (text + 7, pos - text - 7);
+        if (!tmp)
+            return strdup ("");
+        number = strtol (tmp, &error, 10);
+        if (!error || error[0] || (number < 0))
+        {
+            free (tmp);
+            return strdup ("");
+        }
+        free (tmp);
+        return string_repeat (pos + 1, number);
+    }
+
+    /* 8. regex group captured */
     if (strncmp (text, "re:", 3) == 0)
     {
-        if (eval_regex && eval_regex->result)
+        if (eval_context->regex && eval_context->regex->result)
         {
             if (strcmp (text + 3, "+") == 0)
-                number = eval_regex->last_match;
+                number = eval_context->regex->last_match;
             else if (strcmp (text + 3, "#") == 0)
             {
                 snprintf (str_value, sizeof (str_value),
-                          "%d", eval_regex->last_match);
+                          "%d", eval_context->regex->last_match);
                 return strdup (str_value);
             }
             else
@@ -485,17 +495,19 @@ eval_replace_vars_cb (void *data, const char *text)
                 if (!error || error[0])
                     number = -1;
             }
-            if ((number >= 0) && (number <= eval_regex->last_match))
+            if ((number >= 0) && (number <= eval_context->regex->last_match))
             {
                 return string_strndup (
-                    eval_regex->result + eval_regex->match[number].rm_so,
-                    eval_regex->match[number].rm_eo - eval_regex->match[number].rm_so);
+                    eval_context->regex->result +
+                    eval_context->regex->match[number].rm_so,
+                    eval_context->regex->match[number].rm_eo -
+                    eval_context->regex->match[number].rm_so);
             }
         }
         return strdup ("");
     }
 
-    /* 7. color code */
+    /* 9. color code */
     if (strncmp (text, "color:", 6) == 0)
     {
         ptr_value = gui_color_search_config (text + 6);
@@ -505,7 +517,7 @@ eval_replace_vars_cb (void *data, const char *text)
         return strdup ((ptr_value) ? ptr_value : "");
     }
 
-    /* 8. info */
+    /* 10. info */
     if (strncmp (text, "info:", 5) == 0)
     {
         ptr_value = NULL;
@@ -525,7 +537,7 @@ eval_replace_vars_cb (void *data, const char *text)
         return strdup ((ptr_value) ? ptr_value : "");
     }
 
-    /* 9. current date/time */
+    /* 11. current date/time */
     if ((strncmp (text, "date", 4) == 0) && (!text[4] || (text[4] == ':')))
     {
         date = time (NULL);
@@ -538,7 +550,7 @@ eval_replace_vars_cb (void *data, const char *text)
         return strdup ((rc > 0) ? str_value : "");
     }
 
-    /* 10. environment variable */
+    /* 12. environment variable */
     if (strncmp (text, "env:", 4) == 0)
     {
         ptr_value = getenv (text + 4);
@@ -546,23 +558,32 @@ eval_replace_vars_cb (void *data, const char *text)
             return strdup (ptr_value);
     }
 
-    /* 11: ternary operator: if:condition?value_if_true:value_if_false */
+    /* 13: ternary operator: if:condition?value_if_true:value_if_false */
     if (strncmp (text, "if:", 3) == 0)
     {
         value = NULL;
-        pos = (char *)eval_strstr_level (text + 3, "?", prefix, suffix, 1);
+        pos = (char *)eval_strstr_level (text + 3,
+                                         "?",
+                                         eval_context->prefix,
+                                         eval_context->suffix,
+                                         1);
         pos2 = (pos) ?
-            (char *)eval_strstr_level (pos + 1, ":", prefix, suffix, 1) : NULL;
+            (char *)eval_strstr_level (pos + 1,
+                                       ":",
+                                       eval_context->prefix,
+                                       eval_context->suffix,
+                                       1) : NULL;
         condition = (pos) ?
             strndup (text + 3, pos - (text + 3)) : strdup (text + 3);
         if (!condition)
             return strdup ("");
-        tmp = eval_expression_condition (condition, pointers,
-                                         extra_vars, extra_vars_eval,
-                                         prefix, suffix);
-        rc = eval_is_true (tmp);
+        tmp = eval_replace_vars (condition, eval_context);
+        tmp2 = eval_expression_condition ((tmp) ? tmp : "", eval_context);
+        rc = eval_is_true (tmp2);
         if (tmp)
             free (tmp);
+        if (tmp2)
+            free (tmp2);
         if (rc)
         {
             /*
@@ -575,10 +596,7 @@ eval_replace_vars_cb (void *data, const char *text)
                     strndup (pos + 1, pos2 - pos - 1) : strdup (pos + 1);
                 if (tmp)
                 {
-                    value = eval_replace_vars (tmp, pointers,
-                                               extra_vars, extra_vars_eval,
-                                               prefix, suffix,
-                                               eval_regex);
+                    value = eval_replace_vars (tmp, eval_context);
                     free (tmp);
                 }
             }
@@ -595,10 +613,7 @@ eval_replace_vars_cb (void *data, const char *text)
              */
             if (pos2)
             {
-                value = eval_replace_vars (pos2 + 1, pointers,
-                                           extra_vars, extra_vars_eval,
-                                           prefix, suffix,
-                                           eval_regex);
+                value = eval_replace_vars (pos2 + 1, eval_context);
             }
             else
             {
@@ -610,7 +625,7 @@ eval_replace_vars_cb (void *data, const char *text)
         return (value) ? value : strdup ("");
     }
 
-    /* 12. option: if found, return this value */
+    /* 14. option: if found, return this value */
     if (strncmp (text, "sec.data.", 9) == 0)
     {
         ptr_value = hashtable_get (secure_hashtable_data, text + 9);
@@ -643,8 +658,8 @@ eval_replace_vars_cb (void *data, const char *text)
         }
     }
 
-    /* 13. local variable in buffer */
-    ptr_buffer = hashtable_get (pointers, "buffer");
+    /* 15. local variable in buffer */
+    ptr_buffer = hashtable_get (eval_context->pointers, "buffer");
     if (ptr_buffer)
     {
         ptr_value = hashtable_get (ptr_buffer->local_variables, text);
@@ -652,7 +667,7 @@ eval_replace_vars_cb (void *data, const char *text)
             return strdup (ptr_value);
     }
 
-    /* 14. hdata */
+    /* 16. hdata */
     value = NULL;
     hdata_name = NULL;
     list_name = NULL;
@@ -707,7 +722,7 @@ eval_replace_vars_cb (void *data, const char *text)
 
     if (!pointer)
     {
-        pointer = hashtable_get (pointers, hdata_name);
+        pointer = hashtable_get (eval_context->pointers, hdata_name);
         if (!pointer)
             goto end;
     }
@@ -730,24 +745,31 @@ end:
  */
 
 char *
-eval_replace_vars (const char *expr, struct t_hashtable *pointers,
-                   struct t_hashtable *extra_vars, int extra_vars_eval,
-                   const char *prefix, const char *suffix,
-                   struct t_eval_regex *eval_regex)
+eval_replace_vars (const char *expr, struct t_eval_context *eval_context)
 {
-    const void *ptr[6];
     const char *no_replace_prefix_list[] = { "if:", NULL };
+    char *result;
 
-    ptr[0] = pointers;
-    ptr[1] = extra_vars;
-    ptr[2] = &extra_vars_eval;
-    ptr[3] = prefix;
-    ptr[4] = suffix;
-    ptr[5] = eval_regex;
+    eval_context->recursion_count++;
 
-    return string_replace_with_callback (expr, prefix, suffix,
-                                         no_replace_prefix_list,
-                                         &eval_replace_vars_cb, ptr, NULL);
+    if (eval_context->recursion_count < EVAL_RECURSION_MAX)
+    {
+        result = string_replace_with_callback (expr,
+                                               eval_context->prefix,
+                                               eval_context->suffix,
+                                               no_replace_prefix_list,
+                                               &eval_replace_vars_cb,
+                                               eval_context,
+                                               NULL);
+    }
+    else
+    {
+        result = strdup ("");
+    }
+
+    eval_context->recursion_count--;
+
+    return result;
 }
 
 /*
@@ -872,11 +894,7 @@ end:
 
 char *
 eval_expression_condition (const char *expr,
-                           struct t_hashtable *pointers,
-                           struct t_hashtable *extra_vars,
-                           int extra_vars_eval,
-                           const char *prefix,
-                           const char *suffix)
+                           struct t_eval_context *eval_context)
 {
     int logic, comp, length, level, rc;
     const char *pos, *pos_end;
@@ -929,9 +947,7 @@ eval_expression_condition (const char *expr,
             sub_expr = string_strndup (expr2, pos_end + 1 - expr2);
             if (!sub_expr)
                 goto end;
-            tmp_value = eval_expression_condition (sub_expr, pointers,
-                                                   extra_vars, extra_vars_eval,
-                                                   prefix, suffix);
+            tmp_value = eval_expression_condition (sub_expr, eval_context);
             free (sub_expr);
             rc = eval_is_true (tmp_value);
             if (tmp_value)
@@ -951,9 +967,7 @@ eval_expression_condition (const char *expr,
             {
                 pos++;
             }
-            tmp_value = eval_expression_condition (pos, pointers,
-                                                   extra_vars, extra_vars_eval,
-                                                   prefix, suffix);
+            tmp_value = eval_expression_condition (pos, eval_context);
             rc = eval_is_true (tmp_value);
             if (tmp_value)
                 free (tmp_value);
@@ -972,14 +986,21 @@ eval_expression_condition (const char *expr,
     for (comp = 0; comp < EVAL_NUM_COMPARISONS; comp++)
     {
         pos = eval_strstr_level (expr2, comparisons[comp], "(", ")", 0);
-        if (pos > expr2)
+        if (pos >= expr2)
         {
-            pos_end = pos - 1;
-            while ((pos_end > expr2) && (pos_end[0] == ' '))
+            if (pos > expr2)
             {
-                pos_end--;
+                pos_end = pos - 1;
+                while ((pos_end > expr2) && (pos_end[0] == ' '))
+                {
+                    pos_end--;
+                }
+                sub_expr = string_strndup (expr2, pos_end + 1 - expr2);
+            }
+            else
+            {
+                sub_expr = strdup ("");
             }
-            sub_expr = string_strndup (expr2, pos_end + 1 - expr2);
             if (!sub_expr)
                 goto end;
             pos += strlen (comparisons[comp]);
@@ -991,26 +1012,14 @@ eval_expression_condition (const char *expr,
                 || (comp == EVAL_COMPARE_REGEX_NOT_MATCHING))
             {
                 /* for regex: just replace vars in both expressions */
-                tmp_value = eval_replace_vars (sub_expr, pointers,
-                                               extra_vars, extra_vars_eval,
-                                               prefix, suffix,
-                                               NULL);
-                tmp_value2 = eval_replace_vars (pos, pointers,
-                                                extra_vars, extra_vars_eval,
-                                                prefix, suffix,
-                                                NULL);
+                tmp_value = eval_replace_vars (sub_expr, eval_context);
+                tmp_value2 = eval_replace_vars (pos, eval_context);
             }
             else
             {
                 /* other comparison: fully evaluate both expressions */
-                tmp_value = eval_expression_condition (sub_expr, pointers,
-                                                       extra_vars,
-                                                       extra_vars_eval,
-                                                       prefix, suffix);
-                tmp_value2 = eval_expression_condition (pos, pointers,
-                                                        extra_vars,
-                                                        extra_vars_eval,
-                                                        prefix, suffix);
+                tmp_value = eval_expression_condition (sub_expr, eval_context);
+                tmp_value2 = eval_expression_condition (pos, eval_context);
             }
             free (sub_expr);
             value = eval_compare (tmp_value, comp, tmp_value2);
@@ -1048,9 +1057,7 @@ eval_expression_condition (const char *expr,
         sub_expr = string_strndup (expr2 + 1, pos - expr2 - 1);
         if (!sub_expr)
             goto end;
-        tmp_value = eval_expression_condition (sub_expr, pointers,
-                                               extra_vars, extra_vars_eval,
-                                               prefix, suffix);
+        tmp_value = eval_expression_condition (sub_expr, eval_context);
         free (sub_expr);
         if (!pos[1])
         {
@@ -1085,8 +1092,7 @@ eval_expression_condition (const char *expr,
      * at this point, there is no more logical operator neither comparison,
      * so we just replace variables in string and return the result
      */
-    value = eval_replace_vars (expr2, pointers, extra_vars, extra_vars_eval,
-                               prefix, suffix, NULL);
+    value = eval_replace_vars (expr2, eval_context);
 
 end:
     if (expr2)
@@ -1121,12 +1127,11 @@ end:
 
 char *
 eval_replace_regex (const char *string, regex_t *regex, const char *replace,
-                    struct t_hashtable *pointers,
-                    struct t_hashtable *extra_vars, int extra_vars_eval,
-                    const char *prefix, const char *suffix)
+                    struct t_eval_context *eval_context)
 {
     char *result, *result2, *str_replace;
     int length, length_replace, start_offset, i, rc, end;
+    int empty_replace_allowed;
     struct t_eval_regex eval_regex;
 
     if (!string || !regex || !replace)
@@ -1138,8 +1143,14 @@ eval_replace_regex (const char *string, regex_t *regex, const char *replace,
         return NULL;
     snprintf (result, length, "%s", string);
 
+    eval_context->regex = &eval_regex;
+
     start_offset = 0;
-    while (result && result[start_offset])
+
+    /* we allow one empty replace if input string is empty */
+    empty_replace_allowed = (result[0]) ? 0 : 1;
+
+    while (result)
     {
         for (i = 0; i < 100; i++)
         {
@@ -1147,16 +1158,20 @@ eval_replace_regex (const char *string, regex_t *regex, const char *replace,
         }
 
         rc = regexec (regex, result + start_offset, 100, eval_regex.match, 0);
-        /*
-         * no match found: exit the loop (if rm_eo == 0, it is an empty match
-         * at beginning of string: we consider there is no match, to prevent an
-         * infinite loop)
-         */
-        if ((rc != 0)
-            || (eval_regex.match[0].rm_so < 0)
-            || (eval_regex.match[0].rm_eo <= 0))
-        {
+
+        /* no match found: exit the loop */
+        if ((rc != 0) || (eval_regex.match[0].rm_so < 0))
             break;
+
+        /*
+         * if empty string is matching, continue only if empty replace is
+         * still allowed (to prevent infinite loop)
+         */
+        if (eval_regex.match[0].rm_eo <= 0)
+        {
+            if (!empty_replace_allowed)
+                break;
+            empty_replace_allowed = 0;
         }
 
         /* adjust the start/end offsets */
@@ -1176,10 +1191,7 @@ eval_replace_regex (const char *string, regex_t *regex, const char *replace,
 
         eval_regex.result = result;
 
-        str_replace = eval_replace_vars (replace, pointers,
-                                         extra_vars, extra_vars_eval,
-                                         prefix, suffix,
-                                         &eval_regex);
+        str_replace = eval_replace_vars (replace, eval_context);
 
         length_replace = (str_replace) ? strlen (str_replace) : 0;
 
@@ -1211,6 +1223,9 @@ eval_replace_regex (const char *string, regex_t *regex, const char *replace,
             break;
 
         start_offset = eval_regex.match[0].rm_so + length_replace;
+
+        if (!result[start_offset])
+            break;
     }
 
     return result;
@@ -1261,9 +1276,10 @@ char *
 eval_expression (const char *expr, struct t_hashtable *pointers,
                  struct t_hashtable *extra_vars, struct t_hashtable *options)
 {
-    int condition, extra_vars_eval, rc, pointers_allocated, regex_allocated;
+    struct t_eval_context eval_context;
+    int condition, rc, pointers_allocated, regex_allocated;
+    int ptr_window_added, ptr_buffer_added;
     char *value;
-    const char *prefix, *suffix;
     const char *default_prefix = EVAL_DEFAULT_PREFIX;
     const char *default_suffix = EVAL_DEFAULT_SUFFIX;
     const char *ptr_value, *regex_replace;
@@ -1274,13 +1290,12 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
         return NULL;
 
     condition = 0;
-    extra_vars_eval = 0;
     pointers_allocated = 0;
     regex_allocated = 0;
-    prefix = default_prefix;
-    suffix = default_suffix;
     regex = NULL;
     regex_replace = NULL;
+    ptr_window_added = 0;
+    ptr_buffer_added = 0;
 
     if (pointers)
     {
@@ -1299,6 +1314,14 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
         pointers_allocated = 1;
     }
 
+    eval_context.pointers = pointers;
+    eval_context.extra_vars = extra_vars;
+    eval_context.extra_vars_eval = 0;
+    eval_context.prefix = default_prefix;
+    eval_context.suffix = default_suffix;
+    eval_context.regex = NULL;
+    eval_context.recursion_count = 0;
+
     /*
      * set window/buffer with pointer to current window/buffer
      * (if not already defined in the hashtable)
@@ -1306,12 +1329,18 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
     if (gui_current_window)
     {
         if (!hashtable_has_key (pointers, "window"))
+        {
             hashtable_set (pointers, "window", gui_current_window);
+            ptr_window_added = 1;
+        }
         if (!hashtable_has_key (pointers, "buffer"))
         {
             window = (struct t_gui_window *)hashtable_get (pointers, "window");
             if (window)
+            {
                 hashtable_set (pointers, "buffer", window->buffer);
+                ptr_buffer_added = 1;
+            }
         }
     }
 
@@ -1326,17 +1355,17 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
         /* check if extra vars must be evaluated */
         ptr_value = hashtable_get (options, "extra");
         if (ptr_value && (strcmp (ptr_value, "eval") == 0))
-            extra_vars_eval = 1;
+            eval_context.extra_vars_eval = 1;
 
         /* check for custom prefix */
         ptr_value = hashtable_get (options, "prefix");
         if (ptr_value && ptr_value[0])
-            prefix = ptr_value;
+            eval_context.prefix = ptr_value;
 
         /* check for custom suffix */
         ptr_value = hashtable_get (options, "suffix");
         if (ptr_value && ptr_value[0])
-            suffix = ptr_value;
+            eval_context.suffix = ptr_value;
 
         /* check for regex */
         ptr_value = hashtable_get (options, "regex");
@@ -1367,9 +1396,7 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
     if (condition)
     {
         /* evaluate as condition (return a boolean: "0" or "1") */
-        value = eval_expression_condition (expr, pointers,
-                                           extra_vars, extra_vars_eval,
-                                           prefix, suffix);
+        value = eval_expression_condition (expr, &eval_context);
         rc = eval_is_true (value);
         if (value)
             free (value);
@@ -1381,20 +1408,26 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
         {
             /* replace with regex */
             value = eval_replace_regex (expr, regex, regex_replace,
-                                        pointers, extra_vars, extra_vars_eval,
-                                        prefix, suffix);
+                                        &eval_context);
         }
         else
         {
             /* only replace variables in expression */
-            value = eval_replace_vars (expr, pointers,
-                                       extra_vars, extra_vars_eval,
-                                       prefix, suffix, NULL);
+            value = eval_replace_vars (expr, &eval_context);
         }
     }
 
     if (pointers_allocated)
+    {
         hashtable_free (pointers);
+    }
+    else
+    {
+        if (ptr_window_added)
+            hashtable_remove (pointers, "window");
+        if (ptr_buffer_added)
+            hashtable_remove (pointers, "buffer");
+    }
     if (regex && regex_allocated)
     {
         regfree (regex);
