@@ -1,7 +1,7 @@
 /*
  * wee-network.c - network functions
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2010 Emmanuel Bouthenot <kolter@openics.org>
  * Copyright (C) 2010 Gu1ll4um3r0m41n <aeroxteam@gmail.com>
  * Copyright (C) 2012 Simon Arlott
@@ -19,7 +19,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -267,7 +267,8 @@ network_pass_httpproxy (struct t_proxy *proxy, int sock, const char *address,
         snprintf (authbuf, sizeof (authbuf), "%s:%s", username, password);
         free (username);
         free (password);
-        string_encode_base64 (authbuf, strlen (authbuf), authbuf_base64);
+        if (string_base64_encode (authbuf, strlen (authbuf), authbuf_base64) < 0)
+            return 0;
         length = snprintf (buffer, sizeof (buffer),
                            "CONNECT %s:%d HTTP/1.0\r\nProxy-Authorization: "
                            "Basic %s\r\n\r\n",
@@ -344,7 +345,7 @@ network_resolve (const char *hostname, char *ip, int *version)
 /*
  * Establishes a connection and authenticates with a socks4 proxy.
  *
- * The socks4 protocol is explained here: http://en.wikipedia.org/wiki/SOCKS
+ * The socks4 protocol is explained here: https://en.wikipedia.org/wiki/SOCKS
  *
  * WARNING: this function is blocking, it must be called only in a forked
  * process.
@@ -1197,7 +1198,10 @@ network_connect_child (struct t_hook *hook_connect)
             msg.msg_control = msg_buf;
             msg.msg_controllen = sizeof (msg_buf);
 
-            /* send 1 byte of data (not required on Linux, required by BSD/OSX) */
+            /*
+             * send 1 byte of data
+             * (not required on Linux, required by BSD/macOS)
+             */
             memset (iov, 0, sizeof (iov));
             iov[0].iov_base = iov_data;
             iov[0].iov_len = 1;
@@ -1458,7 +1462,10 @@ network_connect_child_read_cb (const void *pointer, void *data, int fd)
                 msg.msg_control = msg_buf;
                 msg.msg_controllen = sizeof (msg_buf);
 
-                /* recv 1 byte of data (not required on Linux, required by BSD/OSX) */
+                /*
+                 * recv 1 byte of data
+                 * (not required on Linux, required by BSD/macOS)
+                 */
                 memset (iov, 0, sizeof (iov));
                 iov[0].iov_base = iov_data;
                 iov[0].iov_len = 1;
