@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_STRING_H
@@ -105,10 +105,12 @@ extern char *string_iconv_from_internal (const char *charset,
                                          const char *string);
 extern int string_fprintf (FILE *file, const char *data, ...);
 extern char *string_format_size (unsigned long long size);
-extern void string_encode_base16 (const char *from, int length, char *to);
-extern int string_decode_base16 (const char *from, char *to);
-extern void string_encode_base64 (const char *from, int length, char *to);
-extern int string_decode_base64 (const char *from, char *to);
+extern int string_base16_encode (const char *from, int length, char *to);
+extern int string_base16_decode (const char *from, char *to);
+extern int string_base32_encode (const char *from, int length, char *to);
+extern int string_base32_decode (const char *from, char *to);
+extern int string_base64_encode (const char *from, int length, char *to);
+extern int string_base64_decode (const char *from, char *to);
 extern char *string_hex_dump (const char *data, int data_size,
                               int bytes_per_line,
                               const char *prefix, const char *suffix);
