@@ -1,7 +1,7 @@
 /*
  * gui-curses-key.c - keyboard functions for Curses GUI
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -180,6 +180,10 @@ gui_key_default_bindings (int context)
         BIND(/* <f10>         */ "meta2-21~",          "/bar scroll title * +30%");
         BIND(/* <f11>         */ "meta2-23~",          "/bar scroll nicklist * -100%");
         BIND(/* <f12>         */ "meta2-24~",          "/bar scroll nicklist * +100%");
+        BIND(/* c-<f11>       */ "meta2-23^",          "/bar scroll nicklist * -100%");
+        BIND(/* c-<f11>       */ "meta2-23;5~",        "/bar scroll nicklist * -100%");
+        BIND(/* c-<f12>       */ "meta2-24^",          "/bar scroll nicklist * +100%");
+        BIND(/* c-<f12>       */ "meta2-24;5~",        "/bar scroll nicklist * +100%");
         BIND(/* m-<f11>       */ "meta2-23;3~",        "/bar scroll nicklist * b");
         BIND(/* m-<f11>       */ "meta-meta2-23~",     "/bar scroll nicklist * b");
         BIND(/* m-<f12>       */ "meta2-24;3~",        "/bar scroll nicklist * e");
@@ -408,8 +412,16 @@ gui_key_flush (int paste)
 
         if (key_str[0])
         {
-            (void) hook_signal_send ("key_pressed",
-                                     WEECHAT_HOOK_SIGNAL_STRING, key_str);
+            /*
+             * send the signal "key_pressed" only if NOT reading a mouse event
+             * or if the mouse code is valid UTF-8 (do not send partial mouse
+             * code which is not UTF-8 valid)
+             */
+            if (!gui_mouse_event_pending || utf8_is_valid (key_str, -1, NULL))
+            {
+                (void) hook_signal_send ("key_pressed",
+                                         WEECHAT_HOOK_SIGNAL_STRING, key_str);
+            }
 
             if (gui_current_window->buffer->text_search != GUI_TEXT_SEARCH_DISABLED)
                 input_old = (gui_current_window->buffer->input_buffer) ?
