@@ -1,7 +1,7 @@
 /*
  * gui-curses-window.c - window display functions for Curses GUI
  *
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -570,6 +570,8 @@ gui_window_emphasize (WINDOW *window, int x, int y, int count)
     else
     {
         /* exclusive or (XOR) with attributes */
+        attrs = 0;
+        pair = 0;
         ptr_attrs = &attrs;
         ptr_pair = &pair;
         wattr_get (window, ptr_attrs, ptr_pair, NULL);
@@ -2507,11 +2509,13 @@ gui_window_send_clipboard (const char *storage_unit, const char *text)
     text_base64 = malloc ((length * 4) + 1);
     if (text_base64)
     {
-        string_encode_base64 (text, length, text_base64);
-        fprintf (stderr, "\033]52;%s;%s\a",
-                 (storage_unit) ? storage_unit : "",
-                 text_base64);
-        fflush (stderr);
+        if (string_base64_encode (text, length, text_base64) >= 0)
+        {
+            fprintf (stderr, "\033]52;%s;%s\a",
+                     (storage_unit) ? storage_unit : "",
+                     text_base64);
+            fflush (stderr);
+        }
         free (text_base64);
     }
 }
@@ -2563,7 +2567,7 @@ gui_window_term_display_infos ()
     gui_chat_printf (NULL, "");
     gui_chat_printf (NULL, _("Terminal infos:"));
     gui_chat_printf (NULL, _("  TERM='%s', size: %dx%d"),
-                     getenv("TERM"), gui_term_cols, gui_term_lines);
+                     getenv ("TERM"), gui_term_cols, gui_term_lines);
 }
 
 /*
