@@ -1,7 +1,7 @@
 /*
  * irc-color.c - IRC color decoding/encoding in messages
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -374,6 +374,11 @@ irc_color_encode (const char *string, int keep_colors)
                     out[out_pos++] = IRC_COLOR_REVERSE_CHAR;
                 ptr_string++;
                 break;
+            case 0x1D: /* ^] */
+                if (keep_colors)
+                    out[out_pos++] = IRC_COLOR_ITALIC_CHAR;
+                ptr_string++;
+                break;
             case 0x1F: /* ^_ */
                 if (keep_colors)
                     out[out_pos++] = IRC_COLOR_UNDERLINE_CHAR;
@@ -481,7 +486,7 @@ irc_color_decode_ansi_cb (void *data, const char *text)
 
     /* sequence "\33[m" resets color */
     if (length < 4)
-        return strdup (weechat_color ("reset"));
+        return strdup (IRC_COLOR_RESET_STR);
 
     text2 = NULL;
     items = NULL;
