@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_PLUGIN_PLUGIN_API_H
@@ -28,6 +28,10 @@ extern void plugin_api_charset_set (struct t_weechat_plugin *plugin,
 extern const char *plugin_api_gettext (const char *string);
 extern const char *plugin_api_ngettext (const char *single, const char *plural,
                                         int count);
+extern int plugin_api_string_base_encode (int base, const char *from,
+                                          int length, char *to);
+extern int plugin_api_string_base_decode (int base, const char *from,
+                                          char *to);
 
 /* config */
 extern void plugin_api_config_file_option_free (struct t_config_option *option);
