@@ -1,7 +1,7 @@
 /*
  * plugin-script.c - common functions used by script plugins
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -346,7 +346,7 @@ plugin_script_ptr2str (void *pointer)
         return str_pointer[index_pointer];
 
     snprintf (str_pointer[index_pointer], sizeof (str_pointer[index_pointer]),
-              "0x%lx", (long unsigned int)pointer);
+              "0x%lx", (unsigned long)pointer);
 
     return str_pointer[index_pointer];
 }
@@ -362,7 +362,7 @@ plugin_script_str2ptr (struct t_weechat_plugin *weechat_plugin,
                        const char *script_name, const char *function_name,
                        const char *str_pointer)
 {
-    long unsigned int value;
+    unsigned long value;
     int rc;
     struct t_gui_buffer *ptr_buffer;
 
