@@ -1,7 +1,7 @@
 /*
  * plugin.c - WeeChat plugins management (load/unload dynamic C libraries)
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -636,8 +636,8 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->string_free_split_command = &string_free_split_command;
         new_plugin->string_format_size = &string_format_size;
         new_plugin->string_remove_color = &gui_color_decode;
-        new_plugin->string_encode_base64 = &string_encode_base64;
-        new_plugin->string_decode_base64 = &string_decode_base64;
+        new_plugin->string_base_encode = &plugin_api_string_base_encode;
+        new_plugin->string_base_decode = &plugin_api_string_base_decode;
         new_plugin->string_hex_dump = &string_hex_dump;
         new_plugin->string_is_command_char = &string_is_command_char;
         new_plugin->string_input_for_buffer = &string_input_for_buffer;
