@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2007 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -15,11 +15,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef WEECHAT_PYTHON_H
-#define WEECHAT_PYTHON_H 1
+#ifndef WEECHAT_PLUGIN_PYTHON_H
+#define WEECHAT_PLUGIN_PYTHON_H
 
 #define weechat_plugin weechat_python_plugin
 #define PYTHON_PLUGIN_NAME "python"
@@ -44,6 +44,8 @@
 
 extern struct t_weechat_plugin *weechat_python_plugin;
 
+extern struct t_plugin_script_data python_data;
+
 extern int python_quiet;
 extern struct t_plugin_script *python_scripts;
 extern struct t_plugin_script *last_python_script;
@@ -61,4 +63,4 @@ extern void *weechat_python_exec (struct t_plugin_script *script,
                                   int ret_type, const char *function,
                                   char *format, void **argv);
 
-#endif /* WEECHAT_PYTHON_H */
+#endif /* WEECHAT_PLUGIN_PYTHON_H */
