@@ -1,7 +1,7 @@
 /*
  * relay-client.c - client functions for relay plugin
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -59,7 +59,7 @@ char *relay_client_data_type_string[] = /* strings for data types           */
 { "text", "binary" };
 
 char *relay_client_msg_type_string[] = /* prefix in raw buffer for message  */
-{ "", "[PING]\n", "[PONG]\n" };
+{ "", "[PING]\n", "[PONG]\n", "[CLOSE]\n" };
 
 struct t_relay_client *relay_clients = NULL;
 struct t_relay_client *last_relay_client = NULL;
@@ -527,6 +527,24 @@ relay_client_recv_text_buffer (struct t_relay_client *client,
                                    strlen (buffer + index + 1),
                                    NULL);
             }
+            else if (msg_type == RELAY_CLIENT_MSG_CLOSE)
+            {
+                /* print message in raw buffer */
+                relay_raw_print (client, RELAY_CLIENT_MSG_CLOSE,
+                                 RELAY_RAW_FLAG_RECV | RELAY_RAW_FLAG_BINARY,
+                                 buffer + index + 1,
+                                 strlen (buffer + index + 1));
+                /* answer with a CLOSE */
+                relay_client_send (client,
+                                   RELAY_CLIENT_MSG_CLOSE,
+                                   buffer + index + 1,
+                                   strlen (buffer + index + 1),
+                                   NULL);
+                /* close the connection */
+                relay_client_set_status (client, RELAY_STATUS_DISCONNECTED);
+                /* ignore any other message after the close */
+                return;
+            }
             index++;
         }
 
@@ -869,6 +887,7 @@ relay_client_send (struct t_relay_client *client,
         raw_size[0] = data_size;
         if ((msg_type == RELAY_CLIENT_MSG_PING)
             || (msg_type == RELAY_CLIENT_MSG_PONG)
+            || (msg_type == RELAY_CLIENT_MSG_CLOSE)
             || ((client->websocket != 1)
                 && (client->send_data_type == RELAY_CLIENT_DATA_BINARY)))
         {
@@ -897,6 +916,9 @@ relay_client_send (struct t_relay_client *client,
             case RELAY_CLIENT_MSG_PONG:
                 opcode = WEBSOCKET_FRAME_OPCODE_PONG;
                 break;
+            case RELAY_CLIENT_MSG_CLOSE:
+                opcode = WEBSOCKET_FRAME_OPCODE_CLOSE;
+                break;
             default:
                 opcode = (client->send_data_type == RELAY_CLIENT_DATA_TEXT) ?
                     WEBSOCKET_FRAME_OPCODE_TEXT : WEBSOCKET_FRAME_OPCODE_BINARY;
@@ -1392,7 +1414,8 @@ relay_client_new_with_infolist (struct t_infolist *infolist)
         new_client->websocket = weechat_infolist_integer (infolist, "websocket");
         new_client->http_headers = NULL;
         new_client->address = strdup (weechat_infolist_string (infolist, "address"));
-        new_client->real_ip = strdup (weechat_infolist_string (infolist, "real_ip"));
+        str = weechat_infolist_string (infolist, "real_ip");
+        new_client->real_ip = (str) ? strdup (str) : NULL;
         new_client->status = weechat_infolist_integer (infolist, "status");
         new_client->protocol = weechat_infolist_integer (infolist, "protocol");
         str = weechat_infolist_string (infolist, "protocol_string");
