@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2007 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -15,11 +15,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef WEECHAT_RUBY_API_H
-#define WEECHAT_RUBY_API_H 1
+#ifndef WEECHAT_PLUGIN_RUBY_API_H
+#define WEECHAT_PLUGIN_RUBY_API_H
 
 extern int weechat_ruby_api_buffer_input_data_cb (const void *pointer,
                                                   void *data,
@@ -30,4 +30,4 @@ extern int weechat_ruby_api_buffer_close_cb (const void *pointer,
                                              struct t_gui_buffer *buffer);
 extern void weechat_ruby_api_init (VALUE ruby_mWeechat);
 
-#endif /* WEECHAT_RUBY_API_H */
+#endif /* WEECHAT_PLUGIN_RUBY_API_H */
