@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,12 +14,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef WEECHAT_SCRIPT_COMPLETION_H
-#define WEECHAT_SCRIPT_COMPLETION_H 1
+#ifndef WEECHAT_PLUGIN_SCRIPT_COMPLETION_H
+#define WEECHAT_PLUGIN_SCRIPT_COMPLETION_H
 
 extern void script_completion_init ();
 
-#endif /* WEECHAT_SCRIPT_COMPLETION_H */
+#endif /* WEECHAT_PLUGIN_SCRIPT_COMPLETION_H */
