@@ -1,7 +1,7 @@
 /*
  * trigger-command.c - trigger command
  *
- * Copyright (C) 2014-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -1222,9 +1222,9 @@ trigger_command_init ()
            "  add text attributes *bold*, _underline_ and /italic/ (only in "
            "user messages):\n"
            "    /trigger add effects modifier weechat_print \"${tg_tag_nick}\" "
-           "\"==\\*(\\S+)\\*==*${color:bold}${re:1}${color:-bold}*== "
-           "==_(\\S+)_==_${color:underline}${re:1}${color:-underline}_== "
-           "==/(\\S+)/==/${color:italic}${re:1}${color:-italic}/\"\n"
+           "\"==\\*([^ ]+)\\*==*${color:bold}${re:1}${color:-bold}*== "
+           "==_([^ ]+)_==_${color:underline}${re:1}${color:-underline}_== "
+           "==/([^ ]+)/==/${color:italic}${re:1}${color:-italic}/\"\n"
            "  hide nicklist bar on small terminals:\n"
            "    /trigger add resize_small signal signal_sigwinch "
            "\"${info:term_width} < 100\" \"\" \"/bar hide nicklist\"\n"
